import {Component, OnInit, Output, ViewChild} from '@angular/core';
import {BusinessComponent} from '../modal/business/business.component';
import { BusinessService } from '../business.service';
import {TreeNodeInterface} from '../../overAll/basic/basic.component';
import {NzMessageService} from 'ng-zorro-antd';
import {color} from '../../app.constants';

@Component({
    selector: 'smart-b-config',
    templateUrl: './b-config.component.html',
    styles: []
})
export class BConfigComponent implements OnInit {
    @ViewChild('smartBusiness') smartBusiness: BusinessComponent;

    sid;  //节点id
    color = color;
    allChecked = false;

    isLoading = false;   //加载中
    dataSet;  //数据list
    expandDataCache = {};

    constructor(private busineSer:BusinessService,private message:NzMessageService) {
    }

    convertTreeToList(root: any, serviceid: string, index): TreeNodeInterface[] {
        const stack = [];
        const array = [];
        const hashMap = {};
        if (root.host == index) {
            stack.push({...root, level: 0, expand: true});
        } else {
            stack.push({...root, level: 0, expand: false});
        }
        while (stack.length !== 0) {
            const node = stack.pop();

            this.visitNode(node, hashMap, array);
            if (node.list) {
                for (let i = node.list.length - 1; i >= 0; i--) {
                    stack.push({...node.list[i], level: node.level + 1, expand: true,serviceid: serviceid, parent: node, checked: false});
                }
            }
        }

        return array;
    }

    visitNode(node: TreeNodeInterface, hashMap: object, array: TreeNodeInterface[]): void {
        if (!hashMap[node.host]) {
            hashMap[node.host] = true;
            array.push(node);
        }
    }

    toTree(index) {
        this.dataSet.forEach(item => {
            this.expandDataCache[item.host] = this.convertTreeToList(item, item.serviceid, index);
        });
    }

    ngOnInit() {
        this.getList();
    }

    //查询业务树
    getList(){
        this.isLoading = true;
        const data = {
            "sid":this.sid,
        };
        this.busineSer.findChild(data).subscribe(
            (res)=>{
                this.isLoading = false;
                if(res.errCode == 10000){
                    this.dataSet = res.data;
                    this.dataSet.forEach((e,index)=>{
                        e.host = index;
                        e.checked = false;
                    })
                    this.toTree(null);
                }else{
                    this.message.error(res.errMsg);
                }
            }
        )
    }

    //
    getChildren(item){
        if (item.list) {
            if (item.expand) {
                item.expand = false;
            } else {
                item.expand = true;
            }
            return false;
        }
        this.isLoading = true;
        const data = {
            "sid":item.serviceid,
        };
        this.busineSer.findChild(data).subscribe(
            (res)=>{
                if (res.data) {
                    this.dataSet[item.host].list = res.data;
                    this.toTree(item.host);
                } else {
                    this.dataSet[item.host].list = [];
                    this.toTree(item.host);
                    this.message.info('该分组下无资源');
                }
                this.isLoading = false;
            }
        )
    }

    //添加业务
    showAddModal() {
        this.smartBusiness.showModal('添加业务');
    }

    //编辑业务
    showEditModal(item){
        this.smartBusiness.showEditModal("编辑业务",item)
    }

}
